==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/model/query/GdzysQuery.java <==
package cn.gtmap.landtax.model.query;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 耕地占用税
 * Created by zhouzhiwei on 2015-03-10.
 */
public class GdzysQuery {
    //税源基本信息
    private String syId;
    private String gdId;
    private String bpId;
    private String sysjly;
    private String djh;
    private String dbh;
    private String syzt;
    private String bz;
    private String ishc;

    // 批次信息
    private String pcId;
    private String pcmc;
    private String pwh;
    private BigDecimal pzmj;
    private BigDecimal nydmj;
    private BigDecimal jbntmj;
    private BigDecimal fgdnydmj;
    private BigDecimal gdmj;
    private Date pzsj;
    private String pcYddw;
    private String pcXzqdm;
    private String pcTdzl;

    // 基本信息
    private String jbbId;
    private String glbm;
    private String nsrmc;
    private String zgkgDm;
    private String zgkgMc;
    private String sgyDm;
    private String sgyMc;
    private String fddbr;
    private String lxdh;
    private String zclxDm;
    private String zclxMc;
    private String hyDm;
    private String hyMc;
    private String zcdz;
    private String tddj;

    // 耕地占用税信息
    private String gdzysId;
    private BigDecimal gdzysYnse;
    private BigDecimal gdzysDwse;
    private String gdzysJmxz;
    private String gdzysJspz;
    private BigDecimal gdzysYjne;
    private BigDecimal gdzysXbjse;
    private String gdzysBz;
    private Date gdzysLrrq;
    private String gdzysHclx;
    private BigDecimal gdzysJmse;

    private String shxrId;
    private String excelBegin;
    private String excelEnd;
    private String ids;

    private String statue;

    public String getSyId() {
        return syId;
    }

    public void setSyId(String syId) {
        this.syId = syId;
    }

    public String getGdId() {
        return gdId;
    }

    public void setGdId(String gdId) {
        this.gdId = gdId;
    }

    public String getBpId() {
        return bpId;
    }

    public void setBpId(String bpId) {
        this.bpId = bpId;
    }

    public String getSysjly() {
        return sysjly;
    }

    public void setSysjly(String sysjly) {
        this.sysjly = sysjly;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getDbh() {
        return dbh;
    }

    public void setDbh(String dbh) {
        this.dbh = dbh;
    }

    public String getSyzt() {
        return syzt;
    }

    public void setSyzt(String syzt) {
        this.syzt = syzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIshc() {
        return ishc;
    }

    public void setIshc(String ishc) {
        this.ishc = ishc;
    }

    public String getPcId() {
        return pcId;
    }

    public void setPcId(String pcId) {
        this.pcId = pcId;
    }

    public String getPcmc() {
        return pcmc;
    }

    public void setPcmc(String pcmc) {
        this.pcmc = pcmc;
    }

    public String getPwh() {
        return pwh;
    }

    public void setPwh(String pwh) {
        this.pwh = pwh;
    }

    public BigDecimal getPzmj() {
        return pzmj;
    }

    public void setPzmj(BigDecimal pzmj) {
        this.pzmj = pzmj;
    }

    public BigDecimal getNydmj() {
        return nydmj;
    }

    public void setNydmj(BigDecimal nydmj) {
        this.nydmj = nydmj;
    }

    public BigDecimal getJbntmj() {
        return jbntmj;
    }

    public void setJbntmj(BigDecimal jbntmj) {
        this.jbntmj = jbntmj;
    }

    public BigDecimal getFgdnydmj() {
        return fgdnydmj;
    }

    public void setFgdnydmj(BigDecimal fgdnydmj) {
        this.fgdnydmj = fgdnydmj;
    }

    public BigDecimal getGdmj() {
        return gdmj;
    }

    public void setGdmj(BigDecimal gdmj) {
        this.gdmj = gdmj;
    }

    public Date getPzsj() {
        return pzsj;
    }

    public void setPzsj(Date pzsj) {
        this.pzsj = pzsj;
    }

    public String getPcYddw() {
        return pcYddw;
    }

    public void setPcYddw(String pcYddw) {
        this.pcYddw = pcYddw;
    }

    public String getPcXzqdm() {
        return pcXzqdm;
    }

    public void setPcXzqdm(String pcXzqdm) {
        this.pcXzqdm = pcXzqdm;
    }

    public String getJbbId() {
        return jbbId;
    }

    public void setJbbId(String jbbId) {
        this.jbbId = jbbId;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getSgyDm() {
        return sgyDm;
    }

    public void setSgyDm(String sgyDm) {
        this.sgyDm = sgyDm;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getZclxDm() {
        return zclxDm;
    }

    public void setZclxDm(String zclxDm) {
        this.zclxDm = zclxDm;
    }

    public String getZclxMc() {
        return zclxMc;
    }

    public void setZclxMc(String zclxMc) {
        this.zclxMc = zclxMc;
    }

    public String getHyDm() {
        return hyDm;
    }

    public void setHyDm(String hyDm) {
        this.hyDm = hyDm;
    }

    public String getHyMc() {
        return hyMc;
    }

    public void setHyMc(String hyMc) {
        this.hyMc = hyMc;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getGdzysId() {
        return gdzysId;
    }

    public void setGdzysId(String gdzysId) {
        this.gdzysId = gdzysId;
    }

    public BigDecimal getGdzysYnse() {
        return gdzysYnse;
    }

    public void setGdzysYnse(BigDecimal gdzysYnse) {
        this.gdzysYnse = gdzysYnse;
    }

    public BigDecimal getGdzysDwse() {
        return gdzysDwse;
    }

    public void setGdzysDwse(BigDecimal gdzysDwse) {
        this.gdzysDwse = gdzysDwse;
    }

    public String getGdzysJmxz() {
        return gdzysJmxz;
    }

    public void setGdzysJmxz(String gdzysJmxz) {
        this.gdzysJmxz = gdzysJmxz;
    }

    public String getGdzysJspz() {
        return gdzysJspz;
    }

    public void setGdzysJspz(String gdzysJspz) {
        this.gdzysJspz = gdzysJspz;
    }

    public BigDecimal getGdzysYjne() {
        return gdzysYjne;
    }

    public void setGdzysYjne(BigDecimal gdzysYjne) {
        this.gdzysYjne = gdzysYjne;
    }

    public BigDecimal getGdzysXbjse() {
        return gdzysXbjse;
    }

    public void setGdzysXbjse(BigDecimal gdzysXbjse) {
        this.gdzysXbjse = gdzysXbjse;
    }

    public String getGdzysBz() {
        return gdzysBz;
    }

    public void setGdzysBz(String gdzysBz) {
        this.gdzysBz = gdzysBz;
    }

    public Date getGdzysLrrq() {
        return gdzysLrrq;
    }

    public void setGdzysLrrq(Date gdzysLrrq) {
        this.gdzysLrrq = gdzysLrrq;
    }

    public String getGdzysHclx() {
        return gdzysHclx;
    }

    public void setGdzysHclx(String gdzysHclx) {
        this.gdzysHclx = gdzysHclx;
    }

    public String getShxrId() {
        return shxrId;
    }

    public void setShxrId(String shxrId) {
        this.shxrId = shxrId;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getStatue() {
        return statue;
    }

    public void setStatue(String statue) {
        this.statue = statue;
    }

    public String getPcTdzl() {
        return pcTdzl;
    }

    public void setPcTdzl(String pcTdzl) {
        this.pcTdzl = pcTdzl;
    }

    public BigDecimal getGdzysJmse() {
        return gdzysJmse;
    }

    public void setGdzysJmse(BigDecimal gdzysJmse) {
        this.gdzysJmse = gdzysJmse;
    }

    public String getTddj() {
        return tddj;
    }

    public void setTddj(String tddj) {
        this.tddj = tddj;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/model/query/GdzysQuery.java <==
package cn.gtmap.landtax.model.query;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 耕地占用税
 * Created by zhouzhiwei on 2015-03-10.
 */
public class GdzysQuery {
    //税源基本信息
    private String syId;
    private String gdId;
    private String bpId;
    private String sysjly;
    private String djh;
    private String dbh;
    private String syzt;
    private String bz;
    private String ishc;

    // 批次信息
    private String pcId;
    private String pcmc;
    private String pwh;
    private BigDecimal pzmj;
    private BigDecimal nydmj;
    private BigDecimal jbntmj;
    private BigDecimal fgdnydmj;
    private BigDecimal gdmj;
    private Date pzsj;
    private String pcYddw;
    private String pcXzqdm;
    private String pcTdzl;

    // 基本信息
    private String jbbId;
    private String nsrsbh;
    private String nsrmc;
    private String zgkgDm;
    private String zgkgMc;
    private String sgyDm;
    private String sgyMc;
    private String fddbr;
    private String lxdh;
    private String zclxDm;
    private String zclxMc;
    private String hyDm;
    private String hyMc;
    private String zcdz;
    private String tddj;

    // 耕地占用税信息
    private String gdzysId;
    private BigDecimal gdzysYnse;
    private BigDecimal gdzysDwse;
    private String gdzysJmxz;
    private String gdzysJspz;
    private BigDecimal gdzysYjne;
    private BigDecimal gdzysXbjse;
    private String gdzysBz;
    private Date gdzysLrrq;
    private String gdzysHclx;
    private BigDecimal gdzysJmse;

    private String shxrId;
    private String excelBegin;
    private String excelEnd;
    private String ids;

    private String statue;

    private String zdsybz;

    public String getZdsybz() {
        return zdsybz;
    }

    public void setZdsybz(String zdsybz) {
        this.zdsybz = zdsybz;
    }


    public String getSyId() {
        return syId;
    }

    public void setSyId(String syId) {
        this.syId = syId;
    }

    public String getGdId() {
        return gdId;
    }

    public void setGdId(String gdId) {
        this.gdId = gdId;
    }

    public String getBpId() {
        return bpId;
    }

    public void setBpId(String bpId) {
        this.bpId = bpId;
    }

    public String getSysjly() {
        return sysjly;
    }

    public void setSysjly(String sysjly) {
        this.sysjly = sysjly;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getDbh() {
        return dbh;
    }

    public void setDbh(String dbh) {
        this.dbh = dbh;
    }

    public String getSyzt() {
        return syzt;
    }

    public void setSyzt(String syzt) {
        this.syzt = syzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIshc() {
        return ishc;
    }

    public void setIshc(String ishc) {
        this.ishc = ishc;
    }

    public String getPcId() {
        return pcId;
    }

    public void setPcId(String pcId) {
        this.pcId = pcId;
    }

    public String getPcmc() {
        return pcmc;
    }

    public void setPcmc(String pcmc) {
        this.pcmc = pcmc;
    }

    public String getPwh() {
        return pwh;
    }

    public void setPwh(String pwh) {
        this.pwh = pwh;
    }

    public BigDecimal getPzmj() {
        return pzmj;
    }

    public void setPzmj(BigDecimal pzmj) {
        this.pzmj = pzmj;
    }

    public BigDecimal getNydmj() {
        return nydmj;
    }

    public void setNydmj(BigDecimal nydmj) {
        this.nydmj = nydmj;
    }

    public BigDecimal getJbntmj() {
        return jbntmj;
    }

    public void setJbntmj(BigDecimal jbntmj) {
        this.jbntmj = jbntmj;
    }

    public BigDecimal getFgdnydmj() {
        return fgdnydmj;
    }

    public void setFgdnydmj(BigDecimal fgdnydmj) {
        this.fgdnydmj = fgdnydmj;
    }

    public BigDecimal getGdmj() {
        return gdmj;
    }

    public void setGdmj(BigDecimal gdmj) {
        this.gdmj = gdmj;
    }

    public Date getPzsj() {
        return pzsj;
    }

    public void setPzsj(Date pzsj) {
        this.pzsj = pzsj;
    }

    public String getPcYddw() {
        return pcYddw;
    }

    public void setPcYddw(String pcYddw) {
        this.pcYddw = pcYddw;
    }

    public String getPcXzqdm() {
        return pcXzqdm;
    }

    public void setPcXzqdm(String pcXzqdm) {
        this.pcXzqdm = pcXzqdm;
    }

    public String getJbbId() {
        return jbbId;
    }

    public void setJbbId(String jbbId) {
        this.jbbId = jbbId;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getSgyDm() {
        return sgyDm;
    }

    public void setSgyDm(String sgyDm) {
        this.sgyDm = sgyDm;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getZclxDm() {
        return zclxDm;
    }

    public void setZclxDm(String zclxDm) {
        this.zclxDm = zclxDm;
    }

    public String getZclxMc() {
        return zclxMc;
    }

    public void setZclxMc(String zclxMc) {
        this.zclxMc = zclxMc;
    }

    public String getHyDm() {
        return hyDm;
    }

    public void setHyDm(String hyDm) {
        this.hyDm = hyDm;
    }

    public String getHyMc() {
        return hyMc;
    }

    public void setHyMc(String hyMc) {
        this.hyMc = hyMc;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getGdzysId() {
        return gdzysId;
    }

    public void setGdzysId(String gdzysId) {
        this.gdzysId = gdzysId;
    }

    public BigDecimal getGdzysYnse() {
        return gdzysYnse;
    }

    public void setGdzysYnse(BigDecimal gdzysYnse) {
        this.gdzysYnse = gdzysYnse;
    }

    public BigDecimal getGdzysDwse() {
        return gdzysDwse;
    }

    public void setGdzysDwse(BigDecimal gdzysDwse) {
        this.gdzysDwse = gdzysDwse;
    }

    public String getGdzysJmxz() {
        return gdzysJmxz;
    }

    public void setGdzysJmxz(String gdzysJmxz) {
        this.gdzysJmxz = gdzysJmxz;
    }

    public String getGdzysJspz() {
        return gdzysJspz;
    }

    public void setGdzysJspz(String gdzysJspz) {
        this.gdzysJspz = gdzysJspz;
    }

    public BigDecimal getGdzysYjne() {
        return gdzysYjne;
    }

    public void setGdzysYjne(BigDecimal gdzysYjne) {
        this.gdzysYjne = gdzysYjne;
    }

    public BigDecimal getGdzysXbjse() {
        return gdzysXbjse;
    }

    public void setGdzysXbjse(BigDecimal gdzysXbjse) {
        this.gdzysXbjse = gdzysXbjse;
    }

    public String getGdzysBz() {
        return gdzysBz;
    }

    public void setGdzysBz(String gdzysBz) {
        this.gdzysBz = gdzysBz;
    }

    public Date getGdzysLrrq() {
        return gdzysLrrq;
    }

    public void setGdzysLrrq(Date gdzysLrrq) {
        this.gdzysLrrq = gdzysLrrq;
    }

    public String getGdzysHclx() {
        return gdzysHclx;
    }

    public void setGdzysHclx(String gdzysHclx) {
        this.gdzysHclx = gdzysHclx;
    }

    public String getShxrId() {
        return shxrId;
    }

    public void setShxrId(String shxrId) {
        this.shxrId = shxrId;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getStatue() {
        return statue;
    }

    public void setStatue(String statue) {
        this.statue = statue;
    }

    public String getPcTdzl() {
        return pcTdzl;
    }

    public void setPcTdzl(String pcTdzl) {
        this.pcTdzl = pcTdzl;
    }

    public BigDecimal getGdzysJmse() {
        return gdzysJmse;
    }

    public void setGdzysJmse(BigDecimal gdzysJmse) {
        this.gdzysJmse = gdzysJmse;
    }

    public String getTddj() {
        return tddj;
    }

    public void setTddj(String tddj) {
        this.tddj = tddj;
    }
}
